@@ -6,4 +6,8 @@ from dataclasses import dataclass
             
 @dataclass
 class User(UserBaseModal):
-    pass           
\ No newline at end of file
+    
+    @classmethod
+    def __meta__(self):
+        
+        return ('id', 'username', 'email')
\ No newline at end of file
