@@ -15,7 +15,7 @@ class UserBaseModal(Model):
     def save(self):
         # check if no User with this username
         # exis
-        if not self.get(username = self.username, id = self.id):
+        if self.get(username = self.username, id = self.id):
             raise DatabaseException('User with this username already exists')
         # hashes the password
         return super().save()
\ No newline at end of file
