@@ -5,6 +5,7 @@ import json
 import copy
 # sorted
 from tesla.database.jsondb.schema import User, settype
+import tesla
 
 ABS_PATH = './db/'
 
@@ -202,12 +203,24 @@ class JsonDB:
         self.collection = collection
         self.abs_path = path
         self.path = path + 'collections/'
+        self.model = None
         ABS_PATH = self.abs_path
+        self.__metas = None
         
          
         if os.path.isdir(self.path  + self.collection) == False:
             os.makedirs(self.path + self.collection)
             self.init_json_db()
+        
+        self.__model__()      
+    
+    def __model__(self):
+        model_n = self.collection[:-1]
+        for m in tesla.TeslaApp.registered_models:
+            
+            if m.__name__ == model_n:
+                self.model = m 
+                
                 
     def init_json_db(self):
             if not os.path.isfile(self.abs_path + 'db.json'):
@@ -227,6 +240,7 @@ class JsonDB:
     
     @classmethod
     def get_collection(cls, model, dept=1):
+        
         if model.title() not in cls.db()['collections']:
             return {
                 'Error': f'No such collection {model}'
@@ -253,24 +267,35 @@ class JsonDB:
             #    local_c_db.set(c.get('id'), c)
                return None
     
-    def all(self):
+    def all(self, json_=False):
         # print(local_db)
-        if local_db.get(self.collection.split('/')[0]):
-           return local_db.get(self.collection.split('/')[0])
+        
+        if json_:
+            lookup = self.collection.split('/')[0] + '_json'
+        else:
+            lookup = self.collection.split('/')[0]    
+        if local_db.get(lookup):
+           return local_db.get(lookup)
         
         all = os.listdir(self.path + self.collection)
         for i in all:
             # c = Column(self.path + self.collection + i)
             with open(self.path + self.collection + i) as fl:
-                c = json.load(fl)
+                
+                js = json.load(fl)
+                if json_:
+                    c = js
+                else:
+                    # print(tesla.TeslaApp.registered_models, self.model)
+                    c = self.model(**js)    
             # print(c.get('id'))
-            local_db.set(self.collection.split('/')[0], c)
+            local_db.set(lookup, c)
             # local_c_db.set(c.get('id'), c)
         # print('here 3')
-        return  local_db.get(self.collection.split('/')[0]) if local_db.get(self.collection.split('/')[0]) else []
+        return local_db.get(self.collection.split('/')[0]) if local_db.get(self.collection.split('/')[0]) else []
         
     def get(self,obj):
-        all = self.all()
+        all = self.all(json_=True)
         # print(all)
         for i in all:
             # print(i, obj)
@@ -320,8 +345,8 @@ class JsonDB:
                if contains:
                    result.append(i)
         return result
-  
-        
+    
+
 # db = DB("users/", User)
 # products = DB("products/", Product)
 # pr1 = products.create_column("watch")
